@@ -23,8 +23,8 @@ import sys
 import logging
 from io import StringIO
 from pathlib import Path
+from warnings import warn
 from atexit import register
-from os.path import join, basename, splitext
 
 from pyszn.parser import find_topology_in_python
 from pyszn.injection import parse_attribute_injection
@@ -49,7 +49,7 @@ def main(args):
     :return: Exit code.
     :rtype: int
     """
-    print('Starting Network Topology Framework v{}'.format(__version__))
+    print('Starting Topology Framework v{}'.format(__version__))
 
     # Setup framework logging
     logmanager.logging_context = None
@@ -61,7 +61,10 @@ def main(args):
     if args.inject is not None:
         injection_spec = parse_attribute_injection(
             args.inject,
-            search_paths=[Path(args.topology).parent])
+            search_paths=[
+                Path(args.topology).parent,
+            ]
+        )
         injected_attr = injection_spec.get(args.topology, None)
 
     # Create manager
@@ -110,29 +113,17 @@ def main(args):
         interact(mgr)
 
     # Plot and export topology
-    module = splitext(basename(args.topology))[0]
     if args.plot_dir:
-        plot_file = join(
-            args.plot_dir, '{}.{}'.format(module, args.plot_format)
-        )
-        mgr.nml.save_graphviz(
-            plot_file, keep_gv=True
-        )
+        warn('--plot-dir is no longer supported, ignoring', DeprecationWarning)
 
     # Export topology as NML
     if args.nml_dir:
-        nml_file = join(
-            args.nml_dir, '{}.xml'.format(module)
-        )
-        mgr.nml.save_nml(
-            nml_file, pretty=True
-        )
+        warn('--nml-dir is no longer supported, ignoring', DeprecationWarning)
 
     return 0
 
 
-if __name__ == '__main__':
-
+def __main__():  # noqa: N807
     # Parse arguments
     try:
         args = parse_args()
@@ -144,6 +135,10 @@ if __name__ == '__main__':
     exit(main(args))
 
 
+if __name__ == '__main__':
+    __main__()
+
+
 __all__ = [
     'main',
 ]
