@@ -20,11 +20,10 @@ Argument management module.
 """
 
 import logging
-from os import getcwd
 from re import compile
 from pprint import pformat
+from os import getcwd, makedirs
 from collections import OrderedDict
-from distutils.dir_util import mkpath
 from argparse import Action, ArgumentParser
 from os.path import join, isabs, abspath, isfile
 
@@ -203,18 +202,6 @@ def validate_args(args):
         )
     args.topology = abspath(args.topology)
 
-    # Determine plot directory and create it if required
-    if args.plot_dir:
-        if not isabs(args.plot_dir):
-            args.plot_dir = join(abspath(getcwd()), args.plot_dir)
-        mkpath(args.nml_dir)
-
-    # Determine NML export directory and create it if required
-    if args.nml_dir:
-        if not isabs(args.nml_dir):
-            args.nml_dir = join(abspath(getcwd()), args.nml_dir)
-        mkpath(args.nml_dir)
-
     # Verify inject file exists
     if args.inject:
         if not isfile(args.inject):
@@ -227,7 +214,7 @@ def validate_args(args):
     if args.log_dir:
         if not isabs(args.log_dir):
             args.log_dir = join(abspath(getcwd()), args.log_dir)
-        mkpath(args.log_dir)
+        makedirs(args.log_dir, exist_ok=True)
 
     # Parse options
     if args.options:
@@ -287,19 +274,28 @@ def parse_args(argv=None):
     parser.add_argument(
         '--plot-dir',
         default=None,
-        help='Directory to auto-plot topologies'
+        help=(
+            'Obsolete. No longer supported. Used in previous versions of '
+            'topology to specify the directory to autoplot topologies'
+        )
     )
     parser.add_argument(
         '--plot-format',
         default='svg',
-        help='Format for plotting topologies'
+        help=(
+            'Obsolete. No longer supported. Used in previous versions of '
+            'topology to specify the plot format'
+        )
     )
 
     # Export options
     parser.add_argument(
         '--nml-dir',
         default=None,
-        help='Directory to export topologies as NML XML'
+        help=(
+            'Obsolete. No longer supported. Used in previous versions of '
+            'topology to specify the directory to export topologies as NML XML'
+        )
     )
 
     # Logging options
