@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2015-2016 Hewlett Packard Enterprise Development LP
+# Copyright (C) 2015-2024 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -39,10 +39,17 @@ class DebugPlatform(BasePlatform):
     See :class:`topology.platforms.platform.BasePlatform` for more information.
     """
 
-    def __init__(self, timestamp, nmlmanager, **kwargs):
+    def __init__(self, timestamp, graph, **kwargs):
         super(DebugPlatform, self).__init__(
-            timestamp, nmlmanager, **kwargs
+            timestamp, graph, **kwargs
         )
+        self.debug_value = 'fordebug'
+
+    def resolve(self):
+        """
+        See :meth:`BasePlatform.resolve` for more information.
+        """
+        log.debug('[HOOK] resolve')
 
     def pre_build(self):
         """
@@ -57,7 +64,7 @@ class DebugPlatform(BasePlatform):
         log.debug('[HOOK] add_node({})'.format(
             node
         ))
-        return DebugNode(node.identifier, name=node.name, **node.metadata)
+        return DebugNode(node.identifier, **node.metadata)
 
     def add_biport(self, node, biport):
         """
